@@ -13,6 +13,8 @@ class PrivateKey:
     passphrase: bytes
 
     def __init__(self, content: bytes, passphrase: bytes = b""):
+        if isinstance(passphrase, str):
+            passphrase = str(passphrase).encode()
         self.passphrase = passphrase
         try:
             private_key_uncrypted = self.load_private_key(content, passphrase)
@@ -35,11 +37,13 @@ class PrivateKey:
             raise PrivateKeyException("Not a valid key")
         return private_key_uncrypted
 
-    @staticmethod
-    def to_pem(private_key: crypto.PKey, passphrase: bytes = None):
+    def to_pem(self, passphrase: bytes = None):
+        """
+        Export the private key to PEM format
+        """
         cipher = "aes256" if passphrase else None
         return crypto.dump_privatekey(
-            crypto.FILETYPE_PEM, private_key, cipher=cipher, passphrase=passphrase
+            crypto.FILETYPE_PEM, self.private_key, cipher=cipher, passphrase=passphrase
         )
 
     def sign(self, content: bytes, algorithm) -> bytes:
